@@ -20,7 +20,7 @@ class Library(object):
     __scenarios = None
     __datasheets = None
     
-    def __init__(self, location=None, session=None):
+    def __init__(self, location=None, session=None, use_conda=None):
         """
         Initializes a pysyncrosim Library instance.
 
@@ -38,6 +38,7 @@ class Library(object):
         """
         self.__location = location
         self.__session = session
+        self.__use_conda = use_conda
 
         # Initialize when in a SyncroSim environment
         if location is None and session is None:
@@ -52,6 +53,9 @@ class Library(object):
         if self.__session is None:
             self.__session = ps.Session()
 
+        if self.__use_conda is not None:
+            self.__init_conda()
+
         self.__name = os.path.basename(self.__location)
         self.__addons = self.__init_addons()
         self.__info = None
@@ -111,6 +115,24 @@ class Library(object):
 
         """
         return self.__location
+
+    @property
+    def use_conda(self):
+        """
+        Retrieves the Conda environment for this Library.
+
+        Returns
+        -------
+        String
+            Conda environment name.
+
+        """
+        return self.__use_conda
+
+    @use_conda.setter
+    def use_conda(self, value):
+        self.__use_conda = value
+        self.__init_conda()
     
     @property
     def package(self):
@@ -381,7 +403,7 @@ class Library(object):
         
     def datasheets(self, name=None, summary=True, optional=False, empty=False,
                    scope="Library", filter_column=None, filter_value=None,
-                   include_key=False, show_full_paths=True, return_hidden=False, *ids):
+                   include_key=False, show_full_paths=False, return_hidden=False, *ids):
         """
         Retrieves a DataFrame of Library Datasheets.
 
@@ -408,7 +430,7 @@ class Library(object):
             to the SQL database. Default is False.
         show_full_paths : Logical, optional
             If set to True, returns the full path of any external files in the 
-            Datasheet. Default is True.
+            Datasheet. Default is False.
         return_hidden : Logical, optional
             If set to True, returns all records in a Datasheet, including those
             hidden from the user. Results in a slower query. Default is False. 
@@ -819,7 +841,38 @@ class Library(object):
             
         # Reset addons
         self.__addons = self.__init_addons()
+
+    def __init_conda(self):
+        args = ["--setprop", "--lib=%s" % self.location]
+
+        if self.__use_conda is True:
+            args += ["--useconda=yes"]
+            current_packages = self.__retrieve_lib_packages()
+            self.__create_conda_env(current_packages)
+        else:
+            args += ["--useconda=no"]
         
+        self.session._Session__call_console(args)
+        
+    def __retrieve_lib_packages(self):
+        # Retrieves current packages being used by the library
+        args = ["--list", "--datasheets", "--lib=%s" % self.location]
+        result = self.session._Session__call_console(args, decode=True, csv=True)
+        result =  pd.read_csv(io.StringIO(result))
+        return np.unique(result["Package"]).tolist()
+
+    def __create_conda_env(self, packages):
+
+        for p in packages:
+            args = ["--conda", "--createenv", "--pkg=%s" % p]
+            result = self.session._Session__call_console(args)
+            result_message = result.stdout.decode('utf-8')
+            if (result.returncode != 0) | \
+                ("this package does not use Conda environments" in result_message):
+                print(result_message)
+                self.__use_conda = False
+                self.__init_conda()
+
     def __init_addons(self):   
         # Retrieves addons information
         args = ["--list", "--addons", "--lib=%s" % self.location]
